# DjangoUserAgents

![PyPI version](https://img.shields.io/pypi/v/uniquetoolkit.svg)
![Python Versions](https://img.shields.io/pypi/pyversions/uniquetoolkit.svg)
![License](https://img.shields.io/pypi/l/uniquetoolkit.svg)


---

## What is DjangoUserAgents?

**DjangoUserAgents** is a **Django library** that ...

---

## Why DjangoUserAgents?

---

License
MIT License — See LICENSE for details.

Links
GitHub: https://github.com/navidsoleymani/djangouseragents

PyPI: https://pypi.org/project/djangouseragents/

Author
Navid Soleymani (Hydra)
Email: navidsoleymani@ymail.com

